<?php
/**
 * MTT Main Class
 * version 2013.04.11
 */

class BL_Many_Tips_Together_Admin
{
	/**
	 * Options default
	 * Configuration of Admin Class
	 * 
	 * @type array 
	 */
	public $config = array(
		'menu'			 => 'settings'
		, 'page_title'	 => 'Many Tips Together'
		, 'capability'	 => 'import'
		, 'option_group'	 => 'ManyTipsTogether'
		, 'id'			 => 'mtt_page'
		, 'fields'		 => array( )
		, 'local_images'	 => true
		, 'use_with_theme' => false
	);
	
	/**
	 * File names for hooks and tabs
	 * 
	 * @var array 
	 */
	private $plugin_sections = array(
		  'adminbar'
		, 'adminmenus'
		, 'appearance'
		, 'dashboard'
		, 'general'
		, 'login'
		, 'maintenance'
		, 'media'
		, 'plugins'
		, 'postediting'
		, 'postlisting'
		, 'profile'
		, 'shortcodes'
		, 'widgets'
	);
	
	/** 
	 * Control extra menus to be removed
	 * @var array 
	 */
	private $default_menus = array( 'index.php', 'edit.php', 'upload.php', 'link-manager.php', 'edit.php?post_type=page', 'edit-comments.php', 'themes.php', 'plugins.php', 'users.php', 'tools.php', 'options-general.php',  'acf-options',  'edit.php?post_type=acf' );


	
	/**
	 * Admin Page Class instance
	 * @var object 
	 */
	public $options_class;

	/**
	 * URL to this plugin's directory.
	 *
	 * @type string
	 */
	public $plugin_url;

	
	/**
	 * Path to this plugin's directory.
	 *
	 * @type string
	 */
	public $plugin_path;

	/**
	 * Options internal holder
	 * 
	 * @type array 
	 */
	public $params = array( );
	
	
	/**
	 * Multisite special condition for this plugin
	 * 
	 * @var boolean 
	 */
	public $multisite = false;

	
	/**
	 * Constructor
	 *
	 * @wp-hook plugins_loaded
	 * @return  void
	 */
	public function __construct( $options )
	{
		// BASIC PARAMETERS
		$this->params		 = $options;
		$this->plugin_url	 = MTT_Plugin_Init::get_url();
		$this->plugin_path	 = MTT_Plugin_Init::get_path();
		$this->multisite	 = is_multisite() 
				? ( is_super_admin() && is_main_site() ) 
				: false;

		// MODIFY CONFIG IF IN MULTISITE
		if( $this->multisite )
		{
			$this->plugin_sections = array_merge( 
					$this->plugin_sections, 
					array( 'multisite' ) 
			);
			$this->config['capability'] = 'manage_network';
		}


		// BUILD ADMIN PAGE
		if( $this->our_page() )
		{
			// MTT custom sidebar
			add_action( 
					'admin_page_class_before_page', 
					array( 'MTT_Plugin_Meta_Box', 'mtt_meta_box' ) 
			);
			// VALIDATION
			add_filter( 
					'apc_validattion_class_name', 
					array( $this, 'set_validation_class' ), 
					10, 2 
			);
			add_filter( 'admin_menu', array( $this, 'get_all_menus' ), 9998 );
		}

		// Plugin script and style
		add_action( 'admin_init', array( $this, 'mtt_admin_init' ) );
		$this->build_admin();

		// LOAD ALL CLASSES
		foreach( $this->plugin_sections as $section )
			require_once ('hooks/' . $section . '.php');

		$this->build_hooks();
		
		
		add_action( "admin_print_scripts", array( $this, 'fix_mp6_bug' ), 9999 );
	}

	public function fix_mp6_bug()
	{
		global $current_screen;
		if( $this->options_class->_Slug != $current_screen->id )
			return;
		if( function_exists( 'mp6_register_admin_color_schemes' ) )
			echo '<style>input.hidden {display:none}#xxx{}</style>';
	}

	/**
	 * Validation Class to be used by APC
	 * 
	 * @param string $class
	 * @return string
	 */
	public function set_validation_class( $validationClassName, $obj )
	{
		if ( $obj->option_group == 'ManyTipsTogether')
				 return 'MTT_Validate_Fields';
		
		return $validationClassName;
	
		$class = 'MTT_Validate_Fields';
		return $class;
	}


	/**
	 * Build admin page
	 *
	 * @wp-hook plugins_loaded
	 * @since   2012.12.21
	 * @return  void
	 */
	public function build_admin()
	{
		// Initiate the admin page
		$options_panel = new BF_Admin_Page_Class( $this->config );
		$options_panel->OpenTabs_container( '' );


		// Define tabs listing
		$tabs_links = array(
			'appearance'	 => __( 'Appearance', 'mtt' ),
			'admin_bar'		 => __( 'Admin Bar', 'mtt' ),
			'admin_menus'	 => __( 'Admin Menus' ),
			'dashboard'		 => __( 'Dashboard', 'mtt' ),
			'post_listing'	 => __( 'Post and Page Listing', 'mtt' ),
			'post_editing'	 => __( 'Post and Page Editing', 'mtt' ),
			'media'			 => __( 'Media', 'mtt' ),
			'widgets'		 => __( 'Widgets', 'mtt' ),
			'plugins'		 => __( 'Plugins', 'mtt' ),
			'user_profile'	 => __( 'Users and Profile', 'mtt' ),
			'shortcodes'	 => __( 'Shortcodes', 'mtt' ),
			'general'		 => __( 'General Settings', 'mtt' ),
			'login_logout'	 => __( 'Login and Logout', 'mtt' ),
			'maintenance'	 => __( 'Maintenance Mode', 'mtt' ),
		);

		// MS support
		if( $this->multisite )
			$tabs_links['multisite'] = __( 'Multisite', 'mtt' );

		// Finish tabs listing
		$tabs_links['credits'] = __( 'Credits', 'mtt' );
		$tabs_links['import_export'] = __( 'Import Export Reset', 'mtt' );

		// Declare tabs listing
		$options_panel->TabsListing( array( 'links' => $tabs_links ) );

		// Include Admin Tabs
		foreach( $this->plugin_sections as $section )
			require_once ('admin-tabs/' . $section . '.php');

		// Special Admin Section
		require_once ('admin-tabs/credits.php');
		
		// Import Export Admin Tabs
		$options_panel->OpenTab( 'import_export' );
		$options_panel->Title( __( 'Import Export Reset', 'mtt' ) );
		$options_panel->addImportExport();
		
		$options_panel->addParagraph( "<hr><h3> Reset</h3>" );
		
		$options_panel->addCheckboxList( 'mtt_reset_plugin', array(
			'do_it' => 'Select this to reset all plugin data.',
				), array(
			'name'	 => 'Reset all plugin data.',
			'desc'	 => '',
			'class'  => 'no-toggle',
			'std'	 => false
		) );
		$options_panel->addCheckboxList( 'mtt_verbose_plugin', array(
			'visible' => '',
				), array(
			'name'	 => '',//Hide help texts
			'class'  => 'mtt-hidden',
			'desc'	 => '', //THIS FIELD IS INVISIBLE, manipulated by MTT meta box
			'std'	 => false
		) );
		$options_panel->addText( 'mtt_version', array(
			'name'	 => '',//INVISIBLE FIELD, version control
			'class'  => 'mtt-hidden',
			'std'	 => ''
		) );
		
		$options_panel->CloseTab();
		

		// End Admin Tabs Container
		$options_panel->CloseTab();


		// Create Admin Interface
		$this->options_class = $options_panel;
	}


	/**
	 * Instantiates all hook classes
	 * 
	 * @wp-hook plugins_loaded
	 * @since   2012.12.21
	 * @return  void
	 */
	public function build_hooks()
	{
		// Shortcircuit the instantiation of specific classes
		global $pagenow;

		// ADMIN BAR
		new MTT_Hook_Adminbar( $this->params );

		// ADMIN MENUS
		if( is_admin() )
			new MTT_Hook_Adminmenus( $this->params );

		// DASHBOARD
		if( 'index.php' == $pagenow && is_admin() )
			new MTT_Hook_Dashboard( $this->params );

		// APPEARENCE
		if( is_admin() )
			new MTT_Hook_Appearance( $this->params );

		// GENERAL
		new MTT_Hook_General( $this->params );

		// LOGIN
		if( 'wp-login.php' == $pagenow )
			new MTT_Hook_Login( $this->params );

		// MAINTENANCE
		new MTT_Hook_Maintenance( $this->params );

		// MEDIA
		new MTT_Hook_Media( $this->params );

		// PLUGINS
		if( is_admin() )
			new MTT_Hook_Plugins( $this->params, $this->multisite );

		// POST EDITING
		if( ( 'post.php' == $pagenow || 'post-new.php' == $pagenow ) && is_admin() )
			new MTT_Hook_Post_Editing( $this->params );

		// POST LISTING
		if(
				( 'edit.php' == $pagenow && is_admin() )
				or
				( 'admin-ajax.php' == $pagenow && isset( $_POST['action'] ) && 'inline-save' == $_POST['action'] )
		)
			new MTT_Hook_Post_Listing( $this->params );

		// PROFILE
		if( ( 'profile.php' == $pagenow || 'user-edit.php' == $pagenow ) && is_admin() )
			new MTT_Hook_Profile( $this->params );

		// SHORTCODES
		new MTT_Hook_Shortcodes( $this->params );

		// WIDGETS
		new MTT_Hook_Widgets( $this->params );

		// MULTISITE
		if( $this->multisite )
			new MTT_Hook_Multisite( $this->params );
	}


	/**
	 * Admin Init Hooks
	 * 
	 */
	public function mtt_admin_init()
	{
		if( defined( 'DOING_AJAX' ) && DOING_AJAX )
			return;
		
		$page = $this->options_class->_Slug;
		
		$cache = MTT_Plugin_Init::$mtt_cache ? time() : null;

		// Basic stuff
		wp_register_style(
				'mtt_admin_css', 
				$this->plugin_url . 'css/admin.css', 
				array( ), 
				$cache
		);
		wp_register_script(
				'mtt_admin_js', 
				$this->plugin_url . 'js/mtt.js', 
				array( ), 
				$cache, 
				true
		);

		add_action( 
				'admin_print_scripts-' . $page, 
				array( $this, 'admin_print_scripts' ), 
				5 
		);

		add_filter( 
				'media_upload_default_tab', 
				array( $this, 'upload_default_tab' ) 
		);
		add_action( 
				'admin_print_styles-media-upload-popup', 
				array( $this, 'upload_popup_style' ) 
		);
	}


	/**
	 * Print plugin style and script
	 */
	public function admin_print_scripts()
	{
		wp_enqueue_style( 'mtt_admin_css' );
		wp_enqueue_script( 'mtt_admin_js' );
		wp_enqueue_script('thickbox');
		wp_enqueue_style('thickbox');

		$network = $this->multisite ? 'network/' : '';
		wp_localize_script(
				'mtt_admin_js'
				, 'mtt'
				, array(
					'title'		 => "Many Tips Together " . __( 'version', 'mtt' ) . MTT_Plugin_Init::$mtt_tb_title,
					'network'	 => $network
				)
		);
	}


	/**
	 * Default tab for Thickbox
	 * 
	 * @param type $tab
	 * @return string
	 */

	public function upload_default_tab( $tab )
	{
		if( !isset( $_GET['apc'] ) )
			return $tab;

		return 'library';
	}


	/**
	 * Hide items in Thickbox
	 * 
	 */
	public function upload_popup_style()
	{
		if( !isset( $_GET['apc'] ) )
			return;
		?>
		<style> tr.post_title, tr.image_alt, tr.post_excerpt, tr.post_content, tr.url, tr.align {display:none;} </style>
		<?php

	}


	/**
	 * Used to get the Options values that startWith
	 * 
	 * @param type $val
	 * @param type $needle
	 * @return type
	 */
	private function filter( $val, $needle )
	{
		$arr = array( );
		foreach( $val as $key => $value )
		{
			if( $this->startsWith( $needle, $key ) )
				$arr[$key] = $val[$key];
		}
		return $arr;
	}


	/**
	 * Search for needle at first position of haystack
	 * 
	 * @param type $needle
	 * @param type $haystack
	 * @return type
	 */
	private function startsWith( $needle, $haystack )
	{
		return !strncmp( $haystack, $needle, strlen( $needle ) );
	}


	/**
	 * Help Tab Callback
	 */
	public function help_tab_callback_two()
	{
		echo '<p><pre>';
		$getty = MTT_Plugin_Utils::print_repository_info( false );
		unset( $getty['changelog'], $getty['sections'], $getty['stats'] );
		print_r( $getty );
		echo '</pre></p>';
	}


	/**
	 * Avoid spilling in other pages
	 * 
	 * @global type $pagenow
	 * @return boolean
	 */
	private function our_page()
	{
		global $pagenow;
		if( 'options-general.php' != $pagenow || !isset( $_GET['page'] ) )
			return false;

		if( strpos( $_GET['page'], $this->our_base_slug() ) === false )
			return false;

		return true;
	}


	/**
	 * Same code APC uses to build the Slug
	 */
	private function our_base_slug()
	{
		$slug	 = str_replace( 
				' ', 
				'_', 
				strtolower( $this->config['page_title'] ) 
		);
		return $slug;
	}

	
	/**
	 * Control extra menus removal. Check if option set or updatable.
	 * 
	 * @global type $menu
	 */
	public function get_all_menus()
	{
	 	global $menu;
		$remove_menus = array();
		foreach( $menu as $m ) 
		{
			if( 
					!in_array( $m[2], $this->default_menus ) 
					&& false === strpos( $m[2], 'separator' ) 
				)
			{
				$remove_menus[ $m[2] ] = $m[0];  
			}
		}
		if( !isset( $this->params['admin_menu_removable_items'] ) || $this->params['admin_menu_removable_items'] != $remove_menus ) 
		{
			$this->params['admin_menu_removable_items'] = $remove_menus;
			update_option( MTT_Plugin_Init::$opt_name, $this->params );
		}
	}

}

