<?php

/**
 * Plugin Name: Many Tips Together
 * Plugin URI: http://wordpress.org/extend/plugins/many-tips-together
 * Description: This plugin compiles many administrative customization tips in one simple interface.
 * Version: 2.1.1
 * Stable Tag: 2.1
 * Author: Rodolfo Buaiz
 * Author URI: http://rodbuaiz.com/
 * Text Domain: mtt
 * Domain Path: /languages
 * License: GPLv2 or later
 *
 * 
 * This program is free software; you can redistribute it and/or modify it under the terms of the GNU 
 * General Public License version 2, as published by the Free Software Foundation.  You may NOT assume 
 * that you can use any other version of the GPL.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without 
 * even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 */


/**
 * SETUP & INIT PLUGIN
 * 
 */
add_action( 'plugins_loaded', array( MTT_Plugin_Init::get_instance(), 'plugin_setup' ) );


/**
 * In depth customization of WordPress administrative interface, plus some other goodies.
 * 
 * @author Rodolfo Buaiz
 * @since 2.0
 * @version 2.0
 * @package Many Tips Together
 * @subpackage 
 */
class MTT_Plugin_Init
{
	/**
	 * Plugin instance.
	 *
	 * @see get_instance()
	 * @type object
	 */
	protected static $instance = NULL;

	/**
	 * Container for Plugin Settings
	 * 
	 * @since 2.0
	 * @type array
	 */
	public $options;

	/**
	 * Options name
	 *
	 * @since 2.0
	 * @type string
	 */
	public static $opt_name		 = 'ManyTipsTogether';

	/**
	 * Plugin version
	 *
	 * @since 1.0
	 * @type string
	 */
	public static $version		 = '2.1.1';

	/**
	 * Plugin title for Thickbox
	 *
	 * @since 1.0
	 * @type string
	 */
	public static $mtt_tb_title	 = ' 2.1.1 &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp; :o[)';

	/**
	 * Development only, no cache for styles/scripts
	 * @var boolean 
	 */
	public static $mtt_cache = false;
	
//private $default_menus = array( 'index.php', 'edit.php', 'upload.php', 'link-manager.php', 'edit.php?post_type=page', 'edit-comments.php', 'themes.php', 'plugins.php', 'users.php', 'tools.php', 'options-general.php',  'acf-options',  'edit.php?post_type=acf' );



	/**
	 * Access this plugin’s working instance
	 *
	 * @wp-hook plugins_loaded
	 * @since   2.0
	 * @return  object of this class
	 */
	public static function get_instance()
	{
		NULL === self::$instance and self::$instance = new self;

		return self::$instance;
	}


	 /**
	 * Used for regular plugin work.
	 *
	 * @wp-hook plugins_loaded
	 * @since   2.0
	 * @return  void
	 */
	public function plugin_setup()
	{
		$this->load_language( 'mtt' );

		// Utilities
		include_once plugin_dir_path( __FILE__ ) . 'inc/class-plugin-utils.php';

		// Plugin Metabox
		include_once plugin_dir_path( __FILE__ ) . 'inc/class-plugin-metabox.php';

		// Admin-Page-Class library
		require_once plugin_dir_path( __FILE__ ) . 'inc/admin-page-class/admin-page-class.php';

		// Admin interface class
		require_once plugin_dir_path( __FILE__ ) . 'inc/class-admin.php';

		// Validation
		include_once plugin_dir_path( __FILE__ ) . 'inc/class-admin-validate.php';

		add_filter( 'plugin_action_links', array( $this, 'settings_plugin_link' ), 10, 2 );
		
//		add_filter( 'admin_menu', array( $this, 'get_all_menus' ), 9998 );

		$this->setup_options();

		new BL_Many_Tips_Together_Admin( $this->options );
	}
		
		
	/**
	 * Constructor. Intentionally left empty and public.
	 *
	 * @see plugin_setup()
	 * @since 2.0
	 */
	public function __construct(){ }



	/**
	 * Plugin URL
	 * @return string 
	 */
	public static function get_url()
	{
		return plugins_url( '/', __FILE__ );
	}


	/**
	 * Plugin system path
	 * @return string 
	 */
	public static function get_path()
	{
		return plugin_dir_path( __FILE__ );
	}


	/**
	 * Plugin directory name
	 * @return string 
	 */
	public static function get_plugin_slug()
	{
		return dirname( plugin_basename( __FILE__ ) );
	}


	/**
	 * First Run <-> Updating Plugin <-> Regular Use 
	 * 
	 * @see plugin_setup()
	 */
	public function setup_options()
	{
		$mtt = get_option( self::$opt_name );
		
		if( !$mtt )
		{
			$mtt			 = MTT_Plugin_Utils::$default_options;
			update_option( self::$opt_name, $mtt );
			$this->options	 = $mtt;
		}
		elseif( version_compare( $mtt['mtt_version'], '2.0', '<' )  )
		{
			$this->options	 = MTT_Plugin_Utils::update_plugin_options( $mtt );
			update_option( self::$opt_name, $this->options );
		}
		else
		{
			$this->options	 = $mtt;
		}
	}


	/**
	 * Add link to settings in Plugins list page
	 * 
	 * @wp-hook plugin_action_links
	 * @return Plugin link
	 */
	public function settings_plugin_link( $links, $file )
	{
		if( $file == plugin_basename( dirname( __FILE__ ) . '/many-tips-together.php' ) )
		{
			$in = '<a href="'
					. admin_url( 'options-general.php?page=options-general.php_many_tips_together' )
					. '">'
					. __( 'Settings' )
					. '</a>';
			array_unshift( $links, $in );
		}
		return $links;
	}


	/**
	 * Loads translation file.
	 * Accessible to other classes to load different language files (admin and
	 * front-end for example).
	 * References:
	 * http://core.trac.wordpress.org/ticket/18960
	 * http://www.geertdedeckere.be/article/loading-wordpress-language-files-the-right-way
	 *
	 * @see plugin_setup()
	 * @param   string $domain
	 * @since   2.0
	 * @return  void
	 */
	public function load_language( $domain )
	{
		$locale = apply_filters( 'plugin_locale', get_locale(), $domain );

		$mo_name = $domain . '-' . $locale . '.mo';
		$mo_path = WP_LANG_DIR . '/plugins/' . self::get_plugin_slug() . '/' . $mo_name;

		load_textdomain( $domain, $mo_path );
		load_plugin_textdomain( $domain, FALSE, self::get_plugin_slug() . '/languages' );
	}


}
